@@ -11,12 +11,14 @@
 #include <QQmlContext>
 
 #include <KPublicTransport/BackendModel>
+#include <KPublicTransport/CoverageArea>
 #include <KPublicTransport/Equipment>
 #include <KPublicTransport/IndividualTransport>
 #include <KPublicTransport/Journey>
 #include <KPublicTransport/JourneyQueryModel>
 #include <KPublicTransport/JourneyRequest>
 #include <KPublicTransport/Line>
+#include <KPublicTransport/LocationHistoryModel>
 #include <KPublicTransport/LocationQueryModel>
 #include <KPublicTransport/LocationRequest>
 #include <KPublicTransport/Manager>
@@ -32,6 +34,8 @@
 
 void KPublicTransportQmlPlugin::registerTypes(const char*)
 {
+    qRegisterMetaType<KPublicTransport::CoverageArea>();
+    qRegisterMetaType<KPublicTransport::CoverageArea::Type>();
     qRegisterMetaType<KPublicTransport::Equipment>();
     qRegisterMetaType<KPublicTransport::Line>();
     qRegisterMetaType<KPublicTransport::Line::Mode>();
@@ -39,6 +43,7 @@ void KPublicTransportQmlPlugin::registerTypes(const char*)
     qRegisterMetaType<KPublicTransport::Location>();
     qRegisterMetaType<KPublicTransport::Platform>();
     qRegisterMetaType<KPublicTransport::RentalVehicle>();
+    qRegisterMetaType<KPublicTransport::RentalVehicleStation>();
     qRegisterMetaType<KPublicTransport::Stopover>();
     qRegisterMetaType<KPublicTransport::IndividualTransport>();
     // backward compat
@@ -47,6 +52,7 @@ void KPublicTransportQmlPlugin::registerTypes(const char*)
     qmlRegisterUncreatableMetaObject(KPublicTransport::Disruption::staticMetaObject, "org.kde.kpublictransport", 1, 0, "Disruption", {});
     qmlRegisterUncreatableMetaObject(KPublicTransport::Load::staticMetaObject, "org.kde.kpublictransport", 1, 0, "Load", {});
 
+    qmlRegisterUncreatableType<KPublicTransport::CoverageArea>("org.kde.kpublictransport", 1, 0, "CoverageArea", {});
     qmlRegisterUncreatableType<KPublicTransport::Line>("org.kde.kpublictransport", 1, 0, "Line", {});
     qmlRegisterUncreatableType<KPublicTransport::Location>("org.kde.kpublictransport", 1, 0, "Location", {});
     qmlRegisterUncreatableType<KPublicTransport::JourneySection>("org.kde.kpublictransport", 1, 0, "JourneySection", {});
@@ -67,6 +73,7 @@ void KPublicTransportQmlPlugin::registerTypes(const char*)
 
     qmlRegisterType<KPublicTransport::Manager>("org.kde.kpublictransport", 1, 0, "Manager");
     qmlRegisterType<KPublicTransport::JourneyQueryModel>("org.kde.kpublictransport", 1, 0, "JourneyQueryModel");
+    qmlRegisterType<KPublicTransport::LocationHistoryModel>("org.kde.kpublictransport", 1, 0, "LocationHistoryModel");
     qmlRegisterType<KPublicTransport::LocationQueryModel>("org.kde.kpublictransport", 1, 0, "LocationQueryModel");
     qmlRegisterType<KPublicTransport::BackendModel>("org.kde.kpublictransport", 1, 0, "BackendModel");
     qmlRegisterType<KPublicTransport::StopoverQueryModel>("org.kde.kpublictransport", 1, 0, "StopoverQueryModel");
